pub enum FileHandleState<Client>{
Read {
request: PrefetchGetObject<Client>,
flushed: bool,
},
Write {
state: UploadState<Client>,
flushed: bool,
},
}Variants
Read
The file handle has been assigned as a read handle
Fields

request: PrefetchGetObject<Client>Write
The file handle has been assigned as a write handle
Implementations
Sourceimpl<Client> FileHandleState<Client>
impl<Client> FileHandleState<Client>
pub async fn new( fh: u64, handle: &NewHandle, flags: OpenFlags, fs: &S3Filesystem<Client>, ) -> Result<FileHandleState<Client>, Error>