S3FuseFilesystem

Struct S3FuseFilesystem 

pub struct S3FuseFilesystem<Client>
where Client: ObjectClient + Clone + Send + Sync + 'static,
{ /* private fields */ }
This is just a thin wrapper around S3Filesystem that implements the actual fuser protocol, so that we can test our actual filesystem implementation without having actual FUSE in the loop.

Implementations

Source

impl<Client> S3FuseFilesystem<Client>
where Client: ObjectClient + Clone + Send + Sync + 'static,

pub fn new( fs: S3Filesystem<Client>, error_logger: Option<Box<dyn ErrorLogger + Send + Sync>>, ) -> Self