pub struct LoggingConfig {
pub log_file: Option<PathBuf>,
pub log_to_stdout: bool,
pub default_filter: String,
}Expand description
Configuration for Mountpoint logging.
This configuration struct is safe to use across forks.
Fields
log_file: Option<PathBuf>File to write logs into. If unspecified, logs will be routed to syslog.
log_to_stdout: boolWhether to duplicate logs to stdout in addition to syslog or the log directory.
default_filter: StringThe default filter directive (in the sense of tracing_subscriber::filter::EnvFilter) to
use for logs. Will be overridden by the MOUNTPOINT_LOG environment variable if set.