pub enum InodeError {
Show 27 variants
ClientError {
source: Arc<Error>,
metadata: Box<ErrorMetadata>,
},
FileDoesNotExist(String, InodeErrorInfo),
InodeDoesNotExist(InodeNo),
InvalidFileName(OsString),
NotADirectory(InodeErrorInfo),
IsDirectory(InodeErrorInfo),
FileAlreadyExists(InodeErrorInfo),
InodeNotWritable(InodeErrorInfo),
InodeInvalidWriteStatus(InodeErrorInfo),
InodeAlreadyWriting(InodeErrorInfo),
InodeNotReadableWhileWriting(InodeErrorInfo),
InodeNotWritableWhileReading(InodeErrorInfo),
CannotRemoveRemoteDirectory(InodeErrorInfo),
DirectoryNotEmpty(InodeErrorInfo),
UnlinkNotPermittedWhileWriting(InodeErrorInfo),
CannotRenameDirectory(InodeErrorInfo),
RenameNotPermittedWhileWriting(InodeErrorInfo),
RenameDestinationExists {
dest_key: String,
src_inode: InodeErrorInfo,
},
RenameNotSupported(),
NameTooLong(String),
CorruptedMetadata(InodeErrorInfo),
SetAttrNotPermittedOnRemoteInode(InodeErrorInfo),
StaleInode {
remote_key: String,
old_inode: InodeErrorInfo,
new_inode: InodeErrorInfo,
},
OperationNotSupportedOnSyntheticInode {
ino: InodeNo,
},
OutOfOrderReadDir {
expected: i64,
actual: i64,
fh: u64,
},
NoSuchDirHandle {
fh: u64,
},
FlexibleRetrievalObjectNotAccessible(InodeErrorInfo),
}Variants
ClientError
Avoid constructing this directly, but use InodeError::client_error instead
FileDoesNotExist(String, InodeErrorInfo)
InodeDoesNotExist(InodeNo)
InvalidFileName(OsString)
NotADirectory(InodeErrorInfo)
IsDirectory(InodeErrorInfo)
FileAlreadyExists(InodeErrorInfo)
InodeNotWritable(InodeErrorInfo)
InodeInvalidWriteStatus(InodeErrorInfo)
InodeAlreadyWriting(InodeErrorInfo)
InodeNotReadableWhileWriting(InodeErrorInfo)
InodeNotWritableWhileReading(InodeErrorInfo)
CannotRemoveRemoteDirectory(InodeErrorInfo)
DirectoryNotEmpty(InodeErrorInfo)
UnlinkNotPermittedWhileWriting(InodeErrorInfo)
CannotRenameDirectory(InodeErrorInfo)
RenameNotPermittedWhileWriting(InodeErrorInfo)
RenameDestinationExists
RenameNotSupported()
NameTooLong(String)
CorruptedMetadata(InodeErrorInfo)
SetAttrNotPermittedOnRemoteInode(InodeErrorInfo)
StaleInode
OperationNotSupportedOnSyntheticInode
OutOfOrderReadDir
NoSuchDirHandle
FlexibleRetrievalObjectNotAccessible(InodeErrorInfo)
Implementations
Sourceimpl InodeError
impl InodeError
Sourcepub fn client_error<E>(
err: E,
context: &'static str,
bucket: &str,
key: &str,
) -> Self
pub fn client_error<E>( err: E, context: &'static str, bucket: &str, key: &str, ) -> Self
Constructs InodeError::ClientError enriching metadata with error_code, bucket and key.
Detailed information about an error is gathered in different frames of the call stack. To make it manageable the idea is to enrich metadata with error_code, bucket and key on the construction of mountpoint crate’s errors, i.e. InodeError, PrefetchReadError and UploadPutError.
pub fn upload_error<E>(err: UploadError<E>, key: S3Location) -> Self
Sourceimpl InodeError
impl InodeError
pub fn meta(&self) -> ErrorMetadata