pub enum ReadWriteMode {
Read,
Write,
}Expand description
The mode in which a handle is provisioned to access the (existing in S3 or local) data for a file (mapped to an inode and backed by a corresponding S3 object)
Variants
Read
Allow reads from this and other concurrent readers (but no writer)
Write
Allow writes from this exclusive writer (but no other writer or readers)