PrefetchGetObject

Struct PrefetchGetObject 

pub struct PrefetchGetObject<Client>
where Client: ObjectClient + Clone + Send + Sync + 'static,
{ /* private fields */ }
Result of a prefetch request. Allows callers to read object data.

Implementations

Source

impl<Client> PrefetchGetObject<Client>
where Client: ObjectClient + Clone + Send + Sync + 'static,

pub async fn read( &mut self, offset: u64, length: usize, ) -> Result<ChecksummedBytes, PrefetchReadError<Client::ClientError>>

Read some bytes from the object. This function will always return exactly size bytes, except at the end of the object where it will return however many bytes are left (including possibly 0 bytes).