pub struct PrefetchGetObject<Client>{ /* private fields */ }Expand description
Result of a prefetch request. Allows callers to read object data.
Implementations
Sourceimpl<Client> PrefetchGetObject<Client>
impl<Client> PrefetchGetObject<Client>
Sourcepub async fn read(
&mut self,
offset: u64,
length: usize,
) -> Result<ChecksummedBytes, PrefetchReadError<Client::ClientError>>
pub async fn read( &mut self, offset: u64, length: usize, ) -> Result<ChecksummedBytes, PrefetchReadError<Client::ClientError>>
Read some bytes from the object. This function will always return exactly size bytes,
except at the end of the object where it will return however many bytes are left (including
possibly 0 bytes).